Documentation
¶
Overview ¶
Description: This package contains the structures to be imported and used by other packages.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthResponse ¶
type AuthResponse struct {
Message string `json:"message"`
User map[string]interface{} `json:"user"`
}
AuthResponse represents the response from an authentication operation.
It includes a message and user information.
type ErrorResponse ¶
ErrorResponse represents a standard error response from the application.
It includes an error code and a message.
type GoogleLogEntry ¶
type GoogleLogEntry struct {
Message string `json:"message"`
Trace string `json:"logging.googleapis.com/trace,omitempty"`
Component string `json:"component,omitempty"`
}
GoogleLogEntry represents a log entry for Google's logging service.
It includes a message, trace, and component information.
type HTTPResponse ¶ added in v1.13.7
HTTPResponse holds the response and error from an HTTP request.
type PaginationOpts ¶
PaginationOpts represents the options for pagination.
It includes a page number and a page size.
type QueryParam ¶
QueryParam represents a query parameter.
It contains a boolean to indicate if multiple values are allowed for a same key.
type ResponseData ¶
ResponseData represents a standard response from the application.
It includes a message and an ID.
type SearchResponse ¶
type SearchResponse struct {
Results []interface{} `json:"results"`
TotalCount int32 `json:"total_count"`
CurrentPage int `json:"current_page"`
LastPage int `json:"last_page"`
}
SearchResponse represents the response from a search operation.
It includes results, total count, current page, and last page.
type TextSearch ¶
TextSearch represents a text search operation.
It includes an index name, a query, and fields to search in.